@@ -43,7 +43,7 @@
 
 class KCurrencyCalculator : public KCurrencyCalculatorDecl
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
