@@ -20,6 +20,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -133,7 +137,7 @@ void KEditLoanWizard::loadWidgets(const MyMoneyAccount& /* account */)
   m_newInterestRateEdit->setPrecision(3);
   m_interestRateLabel->setText(TQString(" ") + ir.formatMoney("", 3) + TQString("%"));
 
-  m_paymentFrequencyUnitEdit->setCurrentItem(i18n(m_schedule.occurenceToString()));
+  m_paymentFrequencyUnitEdit->setCurrentItem(i18n(m_schedule.occurenceToString().utf8()));
   updateTermWidgets(m_account.term());
 
   // the base payment (amortization and interest) is determined
