@@ -38,7 +38,7 @@
 /// This dialog lets the user create or edit an institution
 class KNewBankDlg : public KNewBankDlgDecl
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
