@@ -41,7 +41,7 @@
  */
 class KPayeeReassignDlg : public KPayeeReassignDlgDecl
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   /** Default constructor */
