@@ -153,7 +153,7 @@ void TransactionEditor::slotReloadEditWidgets(void)
 bool TransactionEditor::eventFilter(TQObject* o, TQEvent* e)
 {
   bool rc = false;
-  if(TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(haveWidget("number"))) {
+  if(o == haveWidget("number")) {
     if(e->type() == TQEvent::MouseButtonDblClick) {
       emit assignNumber();
       rc = true;
@@ -180,7 +180,7 @@ bool TransactionEditor::eventFilter(TQObject* o, TQEvent* e)
           // we treat the return/enter key as such.
           if(KMyMoneyGlobalSettings::enterMovesBetweenFields()) {
             for(it_w = m_finalEditWidgets.begin(); !isFinal && it_w != m_finalEditWidgets.end(); ++it_w) {
-              if(TQT_BASE_OBJECT_CONST(*it_w) == TQT_BASE_OBJECT(o)) {
+              if(*it_w == o) {
                 if(dynamic_cast<const kMyMoneyEdit*>(*it_w)) {
                   isFinal = !(dynamic_cast<const kMyMoneyEdit*>(*it_w)->value().isZero());
                 } else
@@ -1744,7 +1744,6 @@ MyMoneyMoney StdTransactionEditor::removeVatSplit(void)
 bool StdTransactionEditor::isComplete(TQString& reason) const
 {
   reason = TQString();
-  // reason.clear();  // for TQt4
 
   TQMap<TQString, TQWidget*>::const_iterator it_w;
   kMyMoneyDateInput* postDate = dynamic_cast<kMyMoneyDateInput*>(m_editWidgets["postdate"]);
