@@ -16,6 +16,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -40,8 +44,6 @@
 
 #ifndef HAVE_CONFIG_H
 #define VERSION "UNKNOWN"
-#else
-#include "config.h"
 #endif
 
 const TQString MyMoneyFile::OpeningBalancesPrefix = I18N_NOOP("Opening Balances");
@@ -739,7 +741,7 @@ const MyMoneyAccount MyMoneyFile::openingBalanceAccount(const MyMoneySecurity& s
       ft.commit();
 
     } catch(MyMoneyException* e) {
-      tqDebug("Unable to create opening balance account for security %s", security.id().data());
+      tqDebug(TQString("Unable to create opening balance account for security %1").arg(security.id()));
       delete e;
     }
     return acc;
@@ -757,7 +759,7 @@ const MyMoneyAccount MyMoneyFile::openingBalanceAccount_internal(const MyMoneySe
     throw new MYMONEYEXCEPTION("Opening balance for non currencies not supported");
 
   MyMoneyAccount acc;
-  TQRegExp match(TQString("^%1").arg(i18n(MyMoneyFile::OpeningBalancesPrefix)));
+  TQRegExp match(TQString("^%1").arg(i18n(MyMoneyFile::OpeningBalancesPrefix.utf8())));
 
   TQValueList<MyMoneyAccount> accounts;
   TQValueList<MyMoneyAccount>::Iterator it;
@@ -785,7 +787,7 @@ const MyMoneyAccount MyMoneyFile::createOpeningBalanceAccount(const MyMoneySecur
   checkTransaction(__PRETTY_FUNCTION__);
 
   MyMoneyAccount acc;
-  TQString name(i18n(MyMoneyFile::OpeningBalancesPrefix));
+  TQString name(i18n(MyMoneyFile::OpeningBalancesPrefix.utf8()));
   if(security.id() != baseCurrency().id()) {
     name += TQString(" (%1)").arg(security.id());
   }
@@ -1099,10 +1101,10 @@ void MyMoneyFile::warningMissingRate(const TQString& fromId, const TQString& toI
   try {
     from = security(fromId);
     to = security(toId);
-    tqWarning("Missing price info for conversion from %s to %s", from.name().latin1(), to.name().latin1());
+    tqWarning(TQString("Missing price info for conversion from %1 to %2").arg(from.name()).arg(to.name()));
 
   } catch(MyMoneyException *e) {
-    tqFatal("Missing security caught in MyMoneyFile::warningMissingRate(): %s(%ld) %s", e->file().data(), e->line(), e->what().data());
+    tqFatal(TQString("Missing security caught in MyMoneyFile::warningMissingRate(): %1(%2) %3").arg(e->file()).arg(e->line()).arg(e->what()));
     delete e;
   }
 }
@@ -1810,11 +1812,11 @@ TQString MyMoneyFile::createCategory(const MyMoneyAccount& base, const TQString&
     }
     catch (MyMoneyException *e)
     {
-      tqDebug("Unable to add account %s, %s, %s: %s",
-        categoryAccount.name().latin1(),
-        parent.name().latin1(),
-        categoryText.latin1(),
-        e->what().latin1());
+      tqDebug(TQString("Unable to add account %1, %2, %3: %4").
+        arg(categoryAccount.name()).
+        arg(parent.name()).
+        arg(categoryText).
+        arg(e->what()));
       delete e;
     }
 
