@@ -54,7 +54,7 @@ namespace KMyMoneyPlugin {
   */
   class KMYMONEY_EXPORT Plugin : public TQObject, public KXMLGUIClient
   {
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     Plugin(TQObject* parent, const char* name);
