@@ -14,10 +14,6 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #ifndef KMYMONEYVIEW_H
 #define KMYMONEYVIEW_H
 
@@ -76,7 +72,7 @@ class KForecastView;
   */
 class KMyMoneyView : public KJanusWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -598,7 +594,7 @@ signals:
   */
 class KMyMoneyViewBase : public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KMyMoneyViewBase(TQWidget* parent, const char *name, const TQString& title);
