@@ -199,7 +199,7 @@ private:
 
 class KPayeesView : public KPayeesViewDecl
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
