@@ -43,7 +43,7 @@ class kMyMoneyAccountCompletion;
   */
 class KMyMoneyAccountCombo : public KComboBox
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KMyMoneyAccountCombo( TQWidget* parent = 0, const char* name = 0 );
