@@ -42,6 +42,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
 // QT Includes
 #include <tqglobal.h>
@@ -53,7 +57,7 @@
 
 // ----------------------------------------------------------------------------
 // KDE Includes
-#include "kdecompat.h"
+#include <tdeversion.h>
 #include <kdatetbl.h> // Use the classes available for maximum re-use
 #include <tdeglobal.h>
 #include <tdeglobalsettings.h>
@@ -82,7 +86,7 @@ kMyMoneyDateTbl::kMyMoneyDateTbl(TQWidget *parent, TQDate date_, const char* nam
     kdDebug() << "kMyMoneyDateTbl ctor: WARNING: Given date is invalid, using current date." << endl;
     date_=TQDate::currentDate();
   }
-  setFocusPolicy( TQ_StrongFocus );
+  setFocusPolicy( TQWidget::StrongFocus );
 
 
   viewport()->setEraseColor(TDEGlobalSettings::baseColor());
