@@ -14,6 +14,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -373,4 +377,4 @@ void KMyMoneyWizard::accept(void)
 }
 
 #include "kmymoneywizard.moc"
-
+#include "kmymoneywizard_p.moc"
