@@ -38,7 +38,7 @@
   */
 class KMyMoneyWizardPagePrivate : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   /**
