@@ -679,7 +679,7 @@ void Register::slotAutoColumnSizing(int section)
 
 bool Register::eventFilter(TQObject* o, TQEvent* e)
 {
-  if(TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(horizontalHeader()) && e->type() == TQEvent::MouseButtonPress) {
+  if(o == horizontalHeader() && e->type() == TQEvent::MouseButtonPress) {
     TQMouseEvent *me = dynamic_cast<TQMouseEvent*>(e);
     if(me->button() == Qt::RightButton) {
       emit headerClicked();
@@ -687,13 +687,13 @@ bool Register::eventFilter(TQObject* o, TQEvent* e)
     // eat up left mouse button press for now
     return true;
 
-  } else if(TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(horizontalHeader()) && e->type() == TQEvent::Paint) {
+  } else if(o == horizontalHeader() && e->type() == TQEvent::Paint) {
     // always show the header in bold (to suppress cell selection)
     TQFont f(horizontalHeader()->font());
     f.setBold(true);
     horizontalHeader()->setFont(f);
 
-  } else if(TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(this) && e->type() == TQEvent::KeyPress) {
+  } else if(o == this && e->type() == TQEvent::KeyPress) {
     TQKeyEvent* ke = dynamic_cast<TQKeyEvent*>(e);
     if(ke->key() == TQt::Key_Menu) {
       emit openContextMenu();
