@@ -45,7 +45,7 @@ namespace KMyMoneyRegister {
   */
 class KMYMONEY_EXPORT RegisterSearchLine : public KLineEdit
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   /**
@@ -109,7 +109,7 @@ private:
   */
 class KMYMONEY_EXPORT RegisterSearchLineWidget : public TQHBox
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   /**
