@@ -34,12 +34,11 @@
 // ----------------------------------------------------------------------------
 // Project Includes
 
+#include <kmymoney/kmymoneysettings.h>
 #include <kmymoney/mymoneyaccount.h>
 #include <kmymoney/mymoneyobject.h>
 #include <kmymoney/register.h>
 
-#include "../kmymoneysettings.h"
-
 class MyMoneyObjectContainer;
 
 namespace KMyMoneyTransactionForm {
@@ -49,7 +48,7 @@ namespace KMyMoneyTransactionForm {
   */
 class TabBar : public TQTabBar
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   typedef enum {
@@ -123,7 +122,7 @@ typedef enum {
   */
 class TransactionForm : public TransactionEditorContainer
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   TransactionForm(TQWidget *parent = 0, const char *name = 0);
@@ -222,4 +221,3 @@ protected:
 } // namespace
 
 #endif
-// vim:cin:si:ai:et:ts=2:sw=2:
