@@ -1,4 +1,4 @@
-/* -*- Mode: C++ -*-
+/*
    KDChart - a multi-platform charting engine
 */
 
@@ -26,17 +26,17 @@
  ** licensing are not clear to you.
  **
  **********************************************************************/
+
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "KDChartLinesPainter.h"
 #include <KDChartParams.h>
 #include <KDChartPropertySet.h>
 
 #include <tqpainter.h>
-
-#if COMPAT_TQT_VERSION >= 0x030000
 #include <tqvaluevector.h>
-#else
-#include <tqarray.h>
-#endif
 
 #include <stdlib.h>
 
@@ -286,11 +286,7 @@ void KDChartLinesPainter::specificPaintData( TQPainter* painter,
          ( dataset >= static_cast < int > ( datasetStart ) && dataset >= 0 );
          --dataset )
         ++arrayNumDatasets;
-#if COMPAT_TQT_VERSION >= 0x030000
     TQValueVector<MyPoint> allPoints(
-#else
-    TQArray<MyPoint> allPoints(
-#endif
                               arrayNumDatasets * arrayNumValues );
                                     
     KDChartPropertySet curPropSet;
